Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(135)

Unified Diff: pkg/analysis_server/lib/src/services/completion/combinator_computer.dart

Issue 1060713005: rename completion computer to contributor (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: merge Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/src/services/completion/combinator_computer.dart
diff --git a/pkg/analysis_server/lib/src/services/completion/combinator_computer.dart b/pkg/analysis_server/lib/src/services/completion/combinator_computer.dart
index 6c296907d0ba1b28b9cb9764019b378ea28b85e8..402d4a2a4113274c3e88df9086689e5464c2bbd1 100644
--- a/pkg/analysis_server/lib/src/services/completion/combinator_computer.dart
+++ b/pkg/analysis_server/lib/src/services/completion/combinator_computer.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library services.completion.computer.dart.combinator;
+library services.completion.contributor.dart.combinator;
import 'dart:async';
@@ -14,10 +14,10 @@ import 'package:analyzer/src/generated/ast.dart';
import 'package:analyzer/src/generated/element.dart';
/**
* A computer for calculating `completion.getSuggestions` request results
* for the import combinators show and hide.
*/
-class CombinatorComputer extends DartCompletionComputer {
+class CombinatorContributor extends DartCompletionContributor {
_CombinatorSuggestionBuilder builder;
@override

Powered by Google App Engine
This is Rietveld 408576698
@@ -14,10 +14,10 @@ import 'package:analyzer/src/generated/ast.dart';
import 'package:analyzer/src/generated/element.dart';
/**
- * A computer for calculating `completion.getSuggestions` request results
+ * A contributor for calculating `completion.getSuggestions` request results
* for the import combinators show and hide.
*/